==> docker-client-6.2.5-sources.jar: com/spotify/docker/client/messages/swarm/UpdateConfig.java <==
/*-
 * -\-\-
 * docker-client
 * --
 * Copyright (C) 2016 Spotify AB
 * --
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * -/-/-
 */

package com.spotify.docker.client.messages.swarm;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.ANY;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.MoreObjects;

import java.util.Objects;

@JsonAutoDetect(fieldVisibility = ANY, getterVisibility = NONE, setterVisibility = NONE)
public class UpdateConfig {

  @JsonProperty("Parallelism")
  private Long parallelism;

  @JsonProperty("Delay")
  private Long delay;

  @JsonProperty("FailureAction")
  private String failureAction;

  public Long parallelism() {
    return parallelism;
  }

  public Long delay() {
    return delay;
  }

  public String failureAction() {
    return failureAction;
  }

  @Override
  public boolean equals(final Object obj) {
    if (this == obj) {
      return true;
    }
    if (obj == null || getClass() != obj.getClass()) {
      return false;
    }

    final UpdateConfig that = (UpdateConfig) obj;

    return Objects.equals(this.parallelism, that.parallelism)
           && Objects.equals(this.delay, that.delay)
           && Objects.equals(this.failureAction, that.failureAction);
  }

  @Override
  public int hashCode() {
    return Objects.hash(parallelism, delay, failureAction);
  }

  @Override
  public String toString() {
    return MoreObjects.toStringHelper(this)
        .add("parallelism", parallelism)
        .add("delay", delay)
        .add("failureAction", failureAction)
        .toString();
  }
}

==> docker-client-7.0.2-sources.jar: com/spotify/docker/client/messages/swarm/UpdateConfig.java <==
/*-
 * -\-\-
 * docker-client
 * --
 * Copyright (C) 2016 Spotify AB
 * --
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * -/-/-
 */

package com.spotify.docker.client.messages.swarm;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.ANY;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.auto.value.AutoValue;


@AutoValue
@JsonAutoDetect(fieldVisibility = ANY, getterVisibility = NONE, setterVisibility = NONE)
public abstract class UpdateConfig {

  @JsonProperty("Parallelism")
  public abstract Long parallelism();

  @JsonProperty("Delay")
  public abstract Long delay();

  @JsonProperty("FailureAction")
  public abstract String failureAction();


  @JsonCreator
  static UpdateConfig create(
      @JsonProperty("Parallelism") final Long parallelism,
      @JsonProperty("Delay") final Long delay,
      @JsonProperty("FailureAction") final String failureAction) {
    return new AutoValue_UpdateConfig(parallelism, delay, failureAction);
  }
}
